##  Step 2. Evaluate Data
In this step, you are now looking at transformation scenarios, transformation impact on the business, application integrations, and project dependencies:
In the Project Landscape Report, cluster the Projects by Objectives to understand how the ERP transformation supports your strategic objectives:
![Project Landscape Report clustered by Objectives](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274dbe357a441014943c85af7ea50b04_LowRes.png)
Project Landscape Report clustered by Objectives
In the Application Landscape Report, you can compare different migration scenarios by mapping Applications to Initiatives, Programs, or Projects:
![Application Landscape Report clustered by Initiatives](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27574ec87a441014b87ddc4f4938cb3a_LowRes.png)
Application Landscape Report clustered by Initiatives
Create a Roadmap Report to get an overview of your high-level Initiatives. To learn more on how to build a transformation roadmap, see [First Steps to Realize Value with Architecture and Road Map Planning](https://help.sap.com/docs/leanix/ea/getting-started-with-sap-leanix-architecture-and-road-map-planning?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a32dd7a441014866efd8d3f9b02f0__first_steps_to_realize_value_with_sap_leanix_architecture_and_road_map_planning). If you apply this to your ERP transformation program, the result of your roadmap can look as follows:
![Roadmap Report showing a high-level overview of Initiatives](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2757957d7a441014b4ef805bb5839f36_LowRes.png)
Roadmap Report showing a high-level overview of Initiatives
Leveraging Architecture and Road Map Planning provides a comprehensive overview of when and how projects are connected to your overarching transformation program. [Milestones](https://help.sap.com/docs/leanix/ea/milestones?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to add and manage milestones and realize their value by effectively visualizing them in reports.") are inherited from the highest level down to all child projects, enabling you to easily visualize their impact on your applications in the Roadmap Report.
Make use of Roadmap Reports to improve decision-making and status reporting. You can add much relevant information from the Fact Sheets, such as Tags, Subscription Roles, and various Fields for better context. It helps enrich the context and increases the collaboration and interactivity of the report.
Bringing these extra details to the Roadmap Report, can help answer questions such as: Who's responsible for a particular application that is currently part of a project within the SAP ERP transformation?
To discover other useful features of Roadmap Reports, refer to [Using the Roadmap Reports](https://help.sap.com/docs/leanix/ea/roadmap-report?locale=en-US&state=PRODUCTION&version=CLOUD#loio275c34e47a441014ad5abfd5bf296fc9__using_the_roadmap_reports)
